==> mingw-w64-gcc-14.1.0-2.src.tar.zst: gcc-14.1.0/gcc/testsuite/gcc.target/riscv/rvv/autovec/gather-scatter/scatter_store_32-5.c <==
/* { dg-do compile } */
/* { dg-additional-options "-march=rv32gcv_zvfh -mabi=ilp32d  -fdump-tree-vect-details" } */

#include <stdint-gcc.h>

#define INDEX16 uint16_t

#define TEST_LOOP(DATA_TYPE, BITS)                                             \
  void __attribute__ ((noinline, noclone))                                     \
  f_##DATA_TYPE (DATA_TYPE *restrict dest, DATA_TYPE *restrict src,            \
		 INDEX##BITS *restrict indices)                                \
  {                                                                            \
    for (int i = 0; i < 128; ++i)                                              \
      dest[indices[i]] = src[i] + 1;                                           \
  }

#define TEST_ALL(T)                                                            \
  T (int8_t, 16)                                                                \
  T (uint8_t, 16)                                                               \
  T (int16_t, 16)                                                               \
  T (uint16_t, 16)                                                              \
  T (_Float16, 16)                                                              \
  T (int32_t, 16)                                                               \
  T (uint32_t, 16)                                                              \
  T (float, 16)                                                                 \
  T (int64_t, 16)                                                               \
  T (uint64_t, 16)                                                              \
  T (double, 16)

TEST_ALL (TEST_LOOP)

/* { dg-final { scan-tree-dump-times "vectorized 1 loops in function" 11 "vect" } } */
/* { dg-final { scan-tree-dump " \.MASK_LEN_SCATTER_STORE" "vect" } } */
/* { dg-final { scan-tree-dump-not " \.SCATTER_STORE" "vect" } } */
/* { dg-final { scan-tree-dump-not " \.MASK_SCATTER_STORE" "vect" } } */
/* { dg-final { scan-assembler-not {vluxei64\.v} } } */
/* { dg-final { scan-assembler-not {vsuxei64\.v} } } */

==> mingw-w64-gcc-15.1.0-8.src.tar.zst: gcc-15.1.0/gcc/testsuite/gcc.target/riscv/rvv/autovec/gather-scatter/scatter_store_64-6.c <==
/* { dg-do compile } */
/* { dg-additional-options "-march=rv64gcv_zvfh -mabi=lp64d  -fdump-tree-vect-details" } */

#include <stdint-gcc.h>

#define INDEX16 int16_t

#define TEST_LOOP(DATA_TYPE, BITS)                                             \
  void __attribute__ ((noinline, noclone))                                     \
  f_##DATA_TYPE (DATA_TYPE *restrict dest, DATA_TYPE *restrict src,            \
		 INDEX##BITS *restrict indices)                                \
  {                                                                            \
    for (int i = 0; i < 128; ++i)                                              \
      dest[indices[i]] = src[i] + 1;                                           \
  }

#define TEST_ALL(T)                                                            \
  T (int8_t, 16)                                                                \
  T (uint8_t, 16)                                                               \
  T (int16_t, 16)                                                               \
  T (uint16_t, 16)                                                              \
  T (_Float16, 16)                                                              \
  T (int32_t, 16)                                                               \
  T (uint32_t, 16)                                                              \
  T (float, 16)                                                                 \
  T (int64_t, 16)                                                               \
  T (uint64_t, 16)                                                              \
  T (double, 16)

TEST_ALL (TEST_LOOP)

/* { dg-final { scan-tree-dump-times "vectorized 1 loops in function" 11 "vect" } } */
/* { dg-final { scan-tree-dump " \.MASK_LEN_SCATTER_STORE" "vect" } } */
/* { dg-final { scan-tree-dump-not " \.SCATTER_STORE" "vect" } } */
/* { dg-final { scan-tree-dump-not " \.MASK_SCATTER_STORE" "vect" } } */
